"use client";

import Image from "next/image";
import { useEffect, useRef } from "react";

import { motion, useScroll, useTransform } from "framer-motion";
import Lenis from "lenis";
import { ArrowDown } from "lucide-react";

import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { ProductHeroData } from "@/utils/get-fake-data";

import { TextAnimate } from "../ui/text-animate";

interface ProductHeroClientProps {
	data: ProductHeroData;
	locale: Locale;
}

export function ProductHeroClient({ data, locale }: ProductHeroClientProps) {
	//   useEffect(() => {
	//     const handleScroll = () => {
	//       setIsScrolled(window.scrollY > 50);
	//     };

	//     window.addEventListener("scroll", handleScroll);
	//     return () => window.removeEventListener("scroll", handleScroll);
	//   }, []);

	const scrollToContent = () => {
		window.scrollTo({
			top: window.innerHeight,
			behavior: "smooth",
		});
	};

	useEffect(() => {
		const lenis = new Lenis();

		function raf(time: number) {
			lenis.raf(time);
			requestAnimationFrame(raf);
		}

		requestAnimationFrame(raf);
	}, []);

	const container = useRef(null);
	const { scrollYProgress } = useScroll({
		target: container,
		offset: ["start start", "end start"],
	});

	const y = useTransform(scrollYProgress, [0, 1], ["0vh", "150vh"]);

	return (
		<section className="relative min-h-screen w-full overflow-hidden">
			<div className="overflow-hidden">
				<div className="absolute inset-0">
					<motion.div style={{ y }} className="relative h-full">
						<Image
							src={data.backgroundImage}
							alt={data.title?.[locale]}
							fill
							style={{ objectFit: "cover" }}
						/>
					</motion.div>
				</div>
			</div>
			{/* Content */}
			<div className="relative z-10 flex min-h-screen flex-col items-start justify-center px-4 text-white lg:gap-16 lg:px-20">
				<div className={cn("max-w-2xl")}>
					<TextAnimate
						once={true}
						animation="blurIn"
						as="p"
						className={cn(
							"mb-10 text-4xl font-normal leading-10 md:text-5xl md:leading-[120px] lg:text-6xl"
						)}
					>
						{data.title?.[locale]}
					</TextAnimate>
					<TextAnimate
						animation="blurIn"
						as="p"
						once={true}
						className={cn(
							"text-justify text-lg leading-8 md:text-xl md:leading-[45px]"
						)}
					>
						{data.description?.[locale]}
					</TextAnimate>
				</div>

				<div
					aria-label={data.scrollButtonText?.[locale]}
					onClick={scrollToContent}
					className="flex h-16 w-16 animate-bounce items-center justify-center rounded-full bg-[#2895C8] text-white transition-all hover:cursor-pointer hover:bg-[#2895C8]/90"
				>
					<ArrowDown className="h-24 w-6" height={24} />
				</div>
				{/* </Button> */}
			</div>
		</section>
	);
}
